#!/usr/bin/env lua

-- NOTE: See beginning of singleton.lua for available configuration variables
--       and their default values.

-- Select interface and port to listen on. NOTE: Some system require different
-- entries for IPv4 and IPv6 while other system use "::" to listen on both
-- IPv4 and IPv6.
listeners = {
  moonbridge_io.tcplisten("::", 6667),
  moonbridge_io.tcplisten("0.0.0.0", 6667)
}

-- If Moonbridge has been compiled with TLS support, uncomment the following
-- section to enable TLS:
--
--[[
tlsconfig = assert(moonbridge_io.tlsconf{
  mode = "server",
  cert_file = "selfsigned.pem",
  key_file = "selfsigned.pem"
})
--]]

-- The Singleton IRC server can connect to a third-party component, which will
-- be capable to inject messages into the system.
--
--[[
uplink = {
  socket = assert(moonbridge_io.tcpconnect("::1", 9000)),
  terminator = "\n",
  handler = function(message)
    local dest, payload = string.match(message, "^(.-) (.*)\n$")
    dest = lower(dest)
    local client = nicks[dest]
    if client then
      client:send(":X!extern@local PRIVMSG ", client.nick, " :", payload)
    else
      local channel = channels[dest]
      if channel then
        channel:send(":X!extern@local PRIVMSG ", dest, " :", payload)
      end
    end
  end
}
--]]

-- The connected_hook can be used to restrict incoming connections (e.g. based
-- on the source IP or other criteria).
--
--[[
function client_prototype:connected_hook()
  return "No connection allowed from " .. self.peer
end
--]]

-- The auth_hook can be used for checking the password.
--
--[[
function client_prototype:auth_hook(nick, pass)
  if pass ~= "secret" then
    return "Password incorrect"
  end
end
--]]

-- The registered_hook gets executed after an IRC client has successfully
-- registered with USER, NICK, and possibly PASS.
--
--[[
function client_prototype:registered_hook()
  self:execute("JOIN", {"#home"})
end
--]]

-- Use nick_hook to restrict nicknames further.
-- NOTE: By default, the Singleton IRC server permits nicknames which are not
-- conforming with RFC2812. To limit nicknames to those patterns specified in
-- RFC2812, use this hook to constrain choice of nickname further.
--
--[[
function client_prototype:nick_hook(nick, lower_nick)
  if lower_nick == "x" or lower_nick == "parrot" then
    return "Nickname is reserved"
  end
end
--]]

-- The join_hook gets called *before* a client joins a channel. The first
-- argument (but self) is the channel object itself. Access the channel's
-- lower-cased name through the lower_name field of this object. The channel
-- name in original spelling (upper and lower case) is passed as a second
-- argument to the hook.
--
--[[
function client_prototype:join_hook(channel, channel_name)
  if #channel.clients > 0 then
    return
  end
  if channel.lower_name == "+forbidden" then
    return "Channel is forbidden"
  end
end
--]]

-- The part_hook gets called *before* a client leaves a channel. Arguments are
-- the same as with the join_hook.
--[[
function client_prototype:part_hook(channel, name)
  if channel.lower_name == "#home" then
    return "Not allowed to leave home channel"
  end
end
--]]

-- The command_hook can be used to intercept any command.
--
--[[
function client_prototype:command_hook()
  if self:is_command("PRIVMSG", 2) then
    if lower(self.params[1]) == "parrot" then
      local message = self.params[2]
      timeout(2, function()
        self:execute("NOTICE", {self.nick, message})
      end)
      return true
    end
  end
end
--]]

